@@ -51,30 +51,20 @@ def _create_template_stream(
     dag_name: str,
     schedule_interval: str,
     image: str,
+    with_external_dependencies: bool,
 ) -> TemplateStream:
     template = _get_jinja_template()
 
     pipeline = context_helper.pipeline
     dependencies = defaultdict(list)
-
-    nodes_with_no_deps = set(node.name for node in pipeline.nodes)
     for node, parent_nodes in pipeline.node_dependencies.items():
         for parent in parent_nodes:
             dependencies[parent].append(node)
-            nodes_with_no_deps = nodes_with_no_deps - set([node.name])
-
-    all_parent_nodes = set()
-    for _, parent_nodes in pipeline.node_dependencies.items():
-        all_parent_nodes = all_parent_nodes.union(
-            set(parent.name for parent in parent_nodes)
-        )
-    bottom_nodes = set(node.name for node in pipeline.nodes) - all_parent_nodes
 
     return template.stream(
         pipeline=pipeline,
         dependencies=dependencies,
-        base_nodes=nodes_with_no_deps,
-        bottom_nodes=bottom_nodes,
+        with_external_dependencies=with_external_dependencies,
         config=context_helper.config,
         resources=_node_resources(
             pipeline.nodes, context_helper.config.run_config.resources
@@ -118,6 +108,7 @@ def get_dag_filename_and_template_stream(
     cron_expression: Optional[str] = None,
     dag_name: Optional[str] = None,
     image: Optional[str] = None,
+    with_external_dependencies: bool = True,
 ):
     config = ctx.obj["context_helper"].config
     dag_name = dag_name or config.run_config.run_name
@@ -129,5 +120,6 @@ def get_dag_filename_and_template_stream(
         dag_name=dag_name,
         schedule_interval=cron_expression,
         image=image or config.run_config.image,
+        with_external_dependencies=with_external_dependencies,
     )
     return dag_filename, template_stream
